@@ -4,7 +4,7 @@
  * GChemPaint
  * standaloneapp.h
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,41 +34,12 @@ public:
 	gcpStandaloneApp();
 	virtual ~gcpStandaloneApp();
 
-	virtual void ActivateMenu(const string& menuname, bool activate);
-	virtual void ToggleMenu(const string& menuname, bool active);
-	virtual void ActivateToolItem(const string& itemname, bool activate);
-	virtual void ClearStatus();
-	virtual void SetStatusText(const char* text);
 	virtual GtkWindow* GetWindow();
-	void OnFileNew();
-	void OnSave();
-	void OnFileOpen();
-	void OnToolClicked (GtkWidget* widget);
-	void OnDoubleClick(GtkWidget* widget);
-	void OnRightClick(GtkWidget* widget);
-	bool OnKeyPressed(GtkWidget* widget, GdkEventKey* ev);
-	bool OnKeyReleased(GtkWidget* widget, GdkEventKey* ev);
-	void OnProperties();
-	void OnPrint();
-	void SetActive (gcpDocument* pDoc, GtkWidget* w);
-	void OnFileClose ();
-	void OnUndo();
-	void OnRedo();
-	void OnSelectAll();
-	void OnPasteSelection();
-	void OnCutSelection();
-	void OnCopySelection();
-	void OnDeleteSelection();
-	void OnCloseAll ();
-	void OnSaveAll ();
-	void Show ();
-
+	void OnFileNew(char const *Theme = NULL);
 	void NoMoreDocsEvent ();
 
 private:
 	GtkWidget* CreateView();
-	void AppendUI (BonoboUINode* Node);
-	void AddToolbar (BonoboUINode* Node, map<unsigned, GtkWidget*> *toolbars = NULL);
 
 private:
 	GtkWindow* m_Window;
